from setuptools import setup

setup(name='Jayanti_distributions',
      version='2.0',
      description='Gaussian distributions and Binomial Distributions',
      packages=['Jayanti_distributions'],
      author='Jayanti Vishnoi',
      author_email='hasbrovish95@gmail.com',
      zip_safe=False)
